@@ -2,13 +2,16 @@ import datetime
 
 import iso8601
 import jwt
+import six
 
 DEFAULT_TTL = 86400
 
+
 class Consumer(object):
     def __init__(self, key):
         self.key = key
 
+
 class User(object):
     def __init__(self, id, consumer, is_admin):
         self.id = id
@@ -17,11 +20,10 @@ class User(object):
 
     @classmethod
     def from_token(cls, token):
-        return cls(
-            token['userId'],
-            Consumer(token['consumerKey']),
-            token.get('admin', False)
-        )
+        return cls(token['userId'],
+                   Consumer(token['consumerKey']),
+                   token.get('admin', False))
+
 
 class Authenticator(object):
     """
@@ -33,8 +35,9 @@ class Authenticator(object):
     def __init__(self, consumer_fetcher):
         """
         Arguments:
-        consumer_fetcher -- a function which takes a consumer key and returns an object
-                            with 'key', 'secret', and 'ttl' attributes
+        consumer_fetcher -- a function which takes a consumer key and returns
+                            an object with 'key', 'secret', and 'ttl'
+                            attributes
         """
         self.consumer_fetcher = consumer_fetcher
 
@@ -73,7 +76,7 @@ class Authenticator(object):
 
         try:
             unsafe_token = decode_token(token, verify=False)
-        except TokenInvalid: # catch junk tokens
+        except TokenInvalid:  # catch junk tokens
             return False
 
         key = unsafe_token.get('consumerKey')
@@ -85,26 +88,38 @@ class Authenticator(object):
             return False
 
         try:
-            return decode_token(token, secret=consumer.secret, ttl=consumer.ttl)
-        except TokenInvalid: # catch inauthentic or expired tokens
+            return decode_token(token,
+                                secret=consumer.secret,
+                                ttl=consumer.ttl)
+        except TokenInvalid:  # catch inauthentic or expired tokens
             return False
 
+
 class TokenInvalid(Exception):
     pass
 
+
 # Main auth routines
+
 def encode_token(token, secret):
     token.update({'issuedAt': _now().isoformat()})
     return jwt.encode(token, secret)
 
+
 def decode_token(token, secret='', ttl=DEFAULT_TTL, verify=True):
     try:
-        token = jwt.decode(str(token), secret, verify=verify)
+        if not type(token) is bytes:
+            if six.PY3:
+                token = bytes(token, 'utf-8')
+            else:
+                token = bytes(token)
+        token = jwt.decode(token, secret, verify=verify)
     except jwt.DecodeError:
         import sys
         exc_class, exc, tb = sys.exc_info()
-        new_exc = TokenInvalid("error decoding JSON Web Token: %s" % exc or exc_class)
-        raise new_exc.__class__, new_exc, tb
+        new_exc = TokenInvalid("error decoding JSON Web Token: %s" %
+                               exc or exc_class)
+        six.reraise(new_exc.__class__, new_exc, tb)
 
     if verify:
         issue_time = token.get('issuedAt')
@@ -121,5 +136,6 @@ def decode_token(token, secret='', ttl=DEFAULT_TTL, verify=True):
 
     return token
 
+
 def _now():
     return datetime.datetime.now(iso8601.iso8601.UTC).replace(microsecond=0)
